package net.sf.itcb.common.business.exceptions;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * Generic exception managing localized message
 * All exceptions has to extend directly or indirectly this class
 * 
 * @author Pierre Le Roux
 *
 */
public class CommonItcbException extends Exception
{

    private static final long serialVersionUID = 1L;
    protected String messageKey;
    protected String message;
    protected String localizedMessage;
    
    protected final Logger log = LoggerFactory.getLogger(getClass());

	public CommonItcbException(ExceptionMappingErrors exceptionMappingErrors, String localizedMessage) {
    	setMessage(exceptionMappingErrors.getMessage());
    	setLocalizedMessage(localizedMessage);
    	setMessageKey(exceptionMappingErrors.getMessageKey());
    	
    	log.error(this.toString());
	}

    @Override
	public String toString() {
    	StackTraceElement methodCaller = this.getStackTrace()[0];
		StringBuilder stringBuilder = new StringBuilder();
		stringBuilder.append(this.getMessageKey());
		stringBuilder.append(" : ");
		stringBuilder.append(this.getMessage());
		stringBuilder.append("\nCause : ");
		stringBuilder.append(methodCaller.toString());
		stringBuilder.append("\nUser message : ");
		stringBuilder.append(this.getLocalizedMessage());
		return stringBuilder.toString();
	}

    public String getMessageKey()
    {
        return messageKey;
    }

    public void setMessageKey(String messageKey)
    {
        this.messageKey = messageKey;
    }

    public String getMessage()
    {
        return message;
    }

    public void setMessage(String message)
    {
        this.message = message;
    }
    
	
    public String getLocalizedMessage() {
		return localizedMessage;
	}

	public void setLocalizedMessage(String localizedMessage) {
		this.localizedMessage = localizedMessage;
	}
    
}
